%define major     15
%define libqs5    %mklibname qscintilla2_qt5_ %{major}
%define libqs5dev %mklibname qscintilla2_qt5 -d

%define libqs6    %mklibname qscintilla2_qt6_ %{major}
%define libqs6dev %mklibname qscintilla2_qt6 -d

%bcond_without	qt5
%bcond_without	qt6

Name:           qscintilla
Version:        2.14.1
Release:        %mkrel 3
Summary:        Port to Qt of Neil Hodgson's Scintilla C++ editor class
License:        GPLv2+
Group:          System/Libraries
URL:            https://riverbankcomputing.com/software/qscintilla/intro
Source0:        https://www.riverbankcomputing.com/static/Downloads/QScintilla/%{version}/QScintilla_src-%{version}.tar.gz
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  sed

# Qt5
%if %{with qt5}
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  python3-qt5-devel
%endif

# Qt6
%if %{with qt6}
BuildRequires:  cmake(Qt6Designer)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  python3-qt6-devel
%endif

# Python 3
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-dbus
BuildRequires:  python3dist(sip)
BuildRequires:  python3-pyqt-builder

%description
As well as features found in standard text editing components,
QScintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

#--------------------------------------------------------------
%if %{with qt5}

%package -n     %{libqs5}
Summary:        Port to Qt5 of Neil Hodgson's Scintilla C++ editor class
Group:          System/Libraries
Requires:       qscintilla2-qt5-common >= %{version}-%{release}
Conflicts:	qscintilla2-qt5-common < 2.13.3

%description -n %{libqs5}
As well as features found in standard text editing components,
QScintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

%files -n %{libqs5}
%{_qt5_libdir}/libqscintilla2_qt5.so.%{major}{,.*}
%{_qt5_plugindir}/designer/libqscintillaplugin.so

#--------------------------------------------------------------

%package -n     %{libqs5dev}
Summary:        Libraries, include and other files to develop applications with QScintilla for Qt5
Group:          Development/KDE and Qt
Requires:       %{libqs5} = %{version}-%{release}
Provides:       %{name}-qt5-devel = %{version}-%{release}
Obsoletes:	%{_lib}qscintilla2-qt5-devel < 2.13.3

%description -n %{libqs5dev}
This packages contains the libraries, include and other files
you can use to develop applications with QScintilla.

%files -n %{libqs5dev}
%{_qt5_includedir}/*
%{_qt5_libdir}/libqscintilla2_qt5.so
%{_qt5_archdatadir}/mkspecs/features/qscintilla2.prf

#--------------------------------------------------------------

%package -n     qscintilla2-qt5-common
Summary:        Common files for %{name}-qt5
Group:          System/Libraries

%description -n qscintilla2-qt5-common
This packages contains translations and designer plugin for %{name}-qt5.

%files -n qscintilla2-qt5-common
%{_qt5_translationdir}/qscintilla*.qm

#--------------------------------------------------------------

%package -n     python3-qt5-qscintilla
Summary:        Python3 Qt5 QScintilla bindings
Group:          Development/KDE and Qt
Requires:       python3-qt5
Requires:       %{libqs5} = %{version}

%description -n python3-qt5-qscintilla
Python3 Qt5 QScintilla bindings.

%files -n python3-qt5-qscintilla
%{python3_sitearch}/PyQt5/Qsci.abi3.so
%{python3_sitearch}/PyQt5/bindings/Qsci/
%{python3_sitearch}/QScintilla-%{version}.dist-info/

#--------------------------------------------------------------

%package        doc-qt5
Summary:        QScintilla docs
Group:          Development/KDE and Qt
BuildArch:      noarch

%description    doc-qt5
QScintilla doc.

%files doc-qt5
%doc NEWS doc
%{_qt5_datadir}/qsci/api/python/*

%endif
#--------------------------------------------------------------
%if %{with qt6}

%package -n     %{libqs6}
Summary:        Port to Qt6 of Neil Hodgson's Scintilla C++ editor class
Group:          System/Libraries
Requires:       qscintilla2-qt6-common >= %{version}-%{release}

%description -n %{libqs6}
As well as features found in standard text editing components,
QScintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

%files -n %{libqs6}
%{_qt6_libdir}/libqscintilla2_qt6.so.%{major}{,.*}
%{_qt6_plugindir}/designer/libqscintillaplugin.so

#--------------------------------------------------------------

%package -n     %{libqs6dev}
Summary:        Libraries, include and other files to develop applications with QScintilla for Qt6
Group:          Development/KDE and Qt
Requires:       %{libqs6} = %{version}-%{release}
Provides:       %{name}-qt6-devel = %{version}-%{release}

%description -n %{libqs6dev}
This packages contains the libraries, include and other files
you can use to develop applications with QScintilla.

%files -n %{libqs6dev}
%{_qt6_includedir}/*
%{_qt6_libdir}/libqscintilla2_qt6.so
%{_qt6_archdatadir}/mkspecs/features/qscintilla2.prf

#--------------------------------------------------------------

%package -n     qscintilla2-qt6-common
Summary:        Common files for %{name}-qt6
Group:          System/Libraries

%description -n qscintilla2-qt6-common
This packages contains translations and designer plugin for %{name}-qt6.

%files -n qscintilla2-qt6-common
%{_qt6_translationdir}/qscintilla*.qm

#--------------------------------------------------------------

%package -n     python3-qt6-qscintilla
Summary:        Python3 Qt6 QScintilla bindings
Group:          Development/KDE and Qt
Requires:       python3-qt6
Requires:       %{libqs6} = %{version}

%description -n python3-qt6-qscintilla
Python3 Qt6 QScintilla bindings.

%files -n python3-qt6-qscintilla
%{python3_sitearch}/PyQt6/Qsci.abi3.so
%{python3_sitearch}/PyQt6/bindings/Qsci/
%{python3_sitearch}/PyQt6_QScintilla-%{version}.dist-info/

#--------------------------------------------------------------

%package        doc-qt6
Summary:        QScintilla docs
Group:          Development/KDE and Qt
BuildArch:      noarch

%description    doc-qt6
QScintilla doc.

%files doc-qt6
%doc NEWS doc
%{_qt6_datadir}/qsci/api/python/*

%endif
#--------------------------------------------------------------

%prep
%setup -qn QScintilla_src-%{version}
%autopatch -p1

%build
export QMAKEFEATURES=$PWD/src/features;

cp -a src src-qt6
%if %{with qt5}
pushd src
  %qmake_qt5 qscintilla.pro
  %make_build
popd
%endif

cp -a designer designer-qt6
%if %{with qt5}
pushd designer
  %qmake_qt5 designer.pro INCLUDEPATH+=../src LIBS+=-L../src
  %make_build
popd
%endif

cp -a Python Python-qt6
%if %{with qt5}
pushd Python
ln -s pyproject-qt5.toml pyproject.toml
LD_LIBRARY_PATH=$PWD/../src sip-build --no-make  --qmake=%{_qt5_bindir}/qmake --api-dir=%{_qt5_datadir}/qsci/api/python --verbose \
    --qsci-include-dir=../src --qsci-library-dir=../src/ --qsci-features-dir=../src/features
%make_build -C build
popd
%endif

%if %{with qt6}
pushd src-qt6
  %qmake_qt6 qscintilla.pro QMAKE_LFLAGS_RPATH=
  %make_build
popd

pushd designer-qt6
  %qmake_qt6 designer.pro QMAKE_LFLAGS_RPATH= INCLUDEPATH-=../src INCLUDEPATH+=../src-qt6 LIBS-=-L../src LIBS+=-L../src-qt6
  %make_build
popd

pushd Python-qt6
ln -s pyproject-qt6.toml pyproject.toml
LD_LIBRARY_PATH=$PWD/../src-qt6 sip-build --no-make  --qmake=%{_qt6_bindir}/qmake --qmake-setting='QMAKE_LFLAGS_RPATH=' --api-dir=%{_qt6_datadir}/qsci/api/python --verbose \
    --qsci-include-dir=../src-qt6 --qsci-library-dir=../src-qt6/ --qsci-features-dir=../src-qt6/features
%make_build -C build
popd
%endif

%install
%if %{with qt5}
%make_install -C src INSTALL_ROOT=%{buildroot}
%make_install -C designer INSTALL_ROOT=%{buildroot}
%make_install -C Python/build INSTALL_ROOT=%{buildroot}
%endif

%if %{with qt6}
%make_install -C src-qt6 INSTALL_ROOT=%{buildroot}
%make_install -C designer-qt6 INSTALL_ROOT=%{buildroot}
%make_install -C Python-qt6/build INSTALL_ROOT=%{buildroot}
%endif

# Drop Python api files
%if %{with qt5}
rm -f %{buildroot}%{_qt5_datadir}/qsci/api/python/Python*.api
%endif
%if %{with qt6}
rm -f %{buildroot}%{_qt6_datadir}/qsci/api/python/Python*.api
%endif


%changelog
* Mon Mar 03 2025 daviddavid <daviddavid> 2.14.1-3.mga10
+ Revision: 2159972
- rebuild for python 3.13

* Wed Dec 20 2023 daviddavid <daviddavid> 2.14.1-2.mga10
+ Revision: 2019990
- rebuild for py3.12

* Thu Sep 21 2023 daviddavid <daviddavid> 2.14.1-1.mga10
+ Revision: 1989224
- new version: 2.14.1

* Sat Jan 28 2023 daviddavid <daviddavid> 2.13.4-1.mga9
+ Revision: 1936629
- new version: 2.13.4
- update Url

* Mon Oct 03 2022 wally <wally> 2.13.3-2.mga9
+ Revision: 1894340
- enable Qt6 build

* Thu May 19 2022 wally <wally> 2.13.3-1.mga9
+ Revision: 1859094
- new version 2.13.3
- sync with Fedora where appropriate
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 2.11.6-3.mga9
+ Revision: 1774684
- rebuild for python-3.10

* Thu Mar 18 2021 daviddavid <daviddavid> 2.11.6-2.mga9
+ Revision: 1704320
- rebuild for python 3.9

* Mon Dec 07 2020 daviddavid <daviddavid> 2.11.6-1.mga8
+ Revision: 1654087
- new version: 2.11.6

* Fri Jun 26 2020 daviddavid <daviddavid> 2.11.5-1.mga8
+ Revision: 1599358
- new version: 2.11.5

* Tue Feb 18 2020 umeabot <umeabot> 2.11.4-2.mga8
+ Revision: 1541140
- Mageia 8 Mass Rebuild

* Sat Dec 21 2019 daviddavid <daviddavid> 2.11.4-1.mga8
+ Revision: 1469331
- new version: 2.11.4

* Sat Nov 23 2019 daviddavid <daviddavid> 2.11.3-1.mga8
+ Revision: 1462291
- new version: 2.11.3

* Wed Sep 18 2019 daviddavid <daviddavid> 2.11.2-4.mga8
+ Revision: 1443589
- time to drop Qt4 support

* Fri Sep 13 2019 daviddavid <daviddavid> 2.11.2-3.mga8
+ Revision: 1440138
- rebuild for python3.8
- drop python2 support

* Sat Jul 27 2019 daviddavid <daviddavid> 2.11.2-2.mga8
+ Revision: 1424532
- rebuild for new Qt5 headers path and new mkspecs macros

* Fri Jul 05 2019 daviddavid <daviddavid> 2.11.2-1.mga8
+ Revision: 1418684
- new version: 2.11.2

* Mon Apr 01 2019 umeabot <umeabot> 2.11.1-6.mga7
+ Revision: 1384271
- Qt5 Rebuild

* Wed Feb 20 2019 daviddavid <daviddavid> 2.11.1-5.mga7
+ Revision: 1368905
- really fix upgrade

* Wed Feb 20 2019 tv <tv> 2.11.1-4.mga7
+ Revision: 1368902
- fix upgrade (aka fix conflicts)

* Wed Feb 20 2019 daviddavid <daviddavid> 2.11.1-3.mga7
+ Revision: 1368763
- split out translations and designer plugin files in separates common sub-pkgs
  thus really fixes conflicting files when libmajor change

* Wed Feb 20 2019 daviddavid <daviddavid> 2.11.1-2.mga7
+ Revision: 1368679
- add conflict to ease upgrade

* Tue Feb 19 2019 daviddavid <daviddavid> 2.11.1-1.mga7
+ Revision: 1368490
- new version: 2.11.1
- now libmajor is 15

* Mon Jan 07 2019 daviddavid <daviddavid> 2.10.8-2.mga7
+ Revision: 1351062
- rebuild for new Python 3.7

* Thu Oct 04 2018 daviddavid <daviddavid> 2.10.8-1.mga7
+ Revision: 1317538
- new version: 2.10.8

* Sun Sep 23 2018 umeabot <umeabot> 2.10.7-3.mga7
+ Revision: 1300676
- Mageia 7 Mass Rebuild

* Tue Jul 31 2018 daviddavid <daviddavid> 2.10.7-2.mga7
+ Revision: 1246300
- rebuild with new sip 4.19.12

* Thu Jul 05 2018 daviddavid <daviddavid> 2.10.7-1.mga7
+ Revision: 1241740
- new version: 2.10.7

* Sun Jun 24 2018 daviddavid <daviddavid> 2.10.5-1.mga7
+ Revision: 1239302
- new version: 2.10.5

* Thu Apr 19 2018 daviddavid <daviddavid> 2.10.4-2.mga7
+ Revision: 1220254
- add conflicts to ease upgrade for mga7

* Thu Apr 19 2018 daviddavid <daviddavid> 2.10.4-1.mga7
+ Revision: 1220171
- new version: 2.10.4
- now libmajor is 13
- now Qt5 library are named libqscintilla2_qt5 instead of qscintilla2-qt5
- now Qt4 library are named libqscintilla2_qt4 instead of qscintilla2
- move the designer plugins into the correct subpkgs
- create a compat symlink for devel subpkgs
- python3 subpkgs requires python3-sip-api and not sip-api
- rename all python-module to python2-module

* Fri Aug 04 2017 daviddavid <daviddavid> 2.9.1-8.mga7
+ Revision: 1134996
- rebuild for new Python 3 and python-sip

* Thu Sep 29 2016 joequant <joequant> 2.9.1-7.mga6
+ Revision: 1057584
- need rebuild to pick up new qt5

* Tue Feb 16 2016 umeabot <umeabot> 2.9.1-6.mga6
+ Revision: 962530
- Mageia 6 Mass Rebuild

* Sat Nov 14 2015 daviddavid <daviddavid> 2.9.1-5.mga6
+ Revision: 903090
- obsoletes some incorrect subpackages < 2.9.1-2

* Mon Nov 09 2015 ns80 <ns80> 2.9.1-4.mga6
+ Revision: 899908
- fix python3-qt4-devel build requirement

* Mon Nov 09 2015 ns80 <ns80> 2.9.1-3.mga6
+ Revision: 899901
- put Qt4 related headers in Qt4 related devel package
+ daviddavid <daviddavid>
- fix requires on qscintilla2-devel subpackage

* Sun Nov 08 2015 akien <akien> 2.9.1-2.mga6
+ Revision: 899258
- Add missing python-qt5 package
- Rename lib packages to match their actual lib names
- Put translation files directly in the lib packages to get rid of i18n subpackages
- Rename python2-qt4-qscintilla to python-qt4-qscintilla

* Sun Nov 08 2015 neoclust <neoclust> 2.9.1-1.mga6
+ Revision: 899213
- New version 2.9.1

* Wed Sep 09 2015 neoclust <neoclust> 2.9-4.mga6
+ Revision: 874750
- Fix provides

* Wed Sep 09 2015 neoclust <neoclust> 2.9-3.mga6
+ Revision: 874715
- Build more with qt5

* Wed Sep 09 2015 fwang <fwang> 2.9-2.mga6
+ Revision: 874675
- qt5 flavour does not build now
- use correct qmake
- update sip dir
- update sysroot
- add more br
- set qt5 as default
- simplified br
- br qt5
- use correct macro
- fix br
- add py3qt5 flavour

* Wed Sep 09 2015 fwang <fwang> 2.9-1.mga6
+ Revision: 874589
- update file list
- 2.9
- 2.8.2
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps

* Mon Mar 17 2014 fwang <fwang> 2.8.1-1.mga5
+ Revision: 604319
- update file list
- fix linkage
- 2.8.1

* Tue Feb 04 2014 fwang <fwang> 2.8-1.mga5
+ Revision: 581702
- update lib major
- new version 2.8

* Sat Oct 19 2013 umeabot <umeabot> 2.7.2-4.mga4
+ Revision: 528936
- Mageia 4 Mass Rebuild
+ fwang <fwang>
- qscintilla does not support build python2 and python3 flavour at the same time
- build py3 sip
- build python3 flavour

* Sat Jun 29 2013 fwang <fwang> 2.7.2-2.mga4
+ Revision: 448375
- move translations out of lib package

* Tue Jun 18 2013 fwang <fwang> 2.7.2-1.mga4
+ Revision: 444336
- update file list
- update file list
- update install prefix
- update dir
- fix ver
- new version 2.7.2

* Sun Jan 13 2013 umeabot <umeabot> 2.7-5.mga3
+ Revision: 379912
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 16 2012 fwang <fwang> 2.7-4.mga3
+ Revision: 331414
- fix obsoletes and conflicts tag

* Tue Dec 11 2012 matteo <matteo> 2.7-3.mga3
+ Revision: 329742
- obsoleting lib qscintilla2_8

* Tue Dec 11 2012 matteo <matteo> 2.7-2.mga3
+ Revision: 329693
- added missing conflict definition

* Tue Dec 11 2012 matteo <matteo> 2.7-1.mga3
+ Revision: 329646
- new version

* Sat Dec 08 2012 fwang <fwang> 2.6.2-2.mga3
+ Revision: 328051
- requires sip api

* Tue Jun 26 2012 fwang <fwang> 2.6.2-1.mga3
+ Revision: 263945
- update includepath
- fix dir
- upload taball
- new version 2.6.2

* Sun Feb 26 2012 matteo <matteo> 2.6.1-1.mga2
+ Revision: 215220
- new version

* Sun Feb 26 2012 matteo <matteo> 2.6-5.mga2
+ Revision: 215162
- fixed wrong qt4 macro
- rebuild needed after pyqt upgrade

* Tue Dec 27 2011 fwang <fwang> 2.6-4.mga2
+ Revision: 188115
- update file list
+ dmorgan <dmorgan>
- Use new qt4 macros

* Mon Dec 26 2011 fwang <fwang> 2.6-3.mga2
+ Revision: 187733
- more accurate obsoletes

* Mon Dec 26 2011 fwang <fwang> 2.6-2.mga2
+ Revision: 187704
- update libmajor
- correct libname

* Mon Dec 26 2011 fwang <fwang> 2.6-1.mga2
+ Revision: 187684
- new version 2.6

* Fri Jul 01 2011 fwang <fwang> 2.5.1-1.mga2
+ Revision: 117090
- new version 2.5.1

* Fri Jan 21 2011 ahmad <ahmad> 2.4.6-2.mga1
+ Revision: 28790
- use the current qt4 Epoch in the qt4-devel BR
- remove the with_qt3 bits; qt3 package wasn't built for a long time anyway
- imported package qscintilla


* Sat Dec 25 2010 Funda Wang <fwang@mandriva.org> 2.4.6-1mdv2011.0
+ Revision: 624706
- update to new version 2.4.6
- rebuild

* Sun Oct 31 2010 Funda Wang <fwang@mandriva.org> 2.4.5-2mdv2011.0
+ Revision: 590744
- rebuild for py2.7

* Wed Sep 01 2010 Funda Wang <fwang@mandriva.org> 2.4.5-1mdv2011.0
+ Revision: 575017
- new version 2.4.5

* Thu Jul 15 2010 Funda Wang <fwang@mandriva.org> 2.4.4-1mdv2011.0
+ Revision: 553427
- new version 2.4.4

* Thu Mar 18 2010 Funda Wang <fwang@mandriva.org> 2.4.3-1mdv2010.1
+ Revision: 524770
- new version 2.4.3

* Thu Jan 21 2010 Funda Wang <fwang@mandriva.org> 2.4.2-1mdv2010.1
+ Revision: 494593
- New version 2.4.2

* Sat Jan 09 2010 Funda Wang <fwang@mandriva.org> 2.4-6mdv2010.1
+ Revision: 488141
- rebuild for new sip

* Mon Sep 28 2009 Helio Chissini de Castro <helio@mandriva.com> 2.4-5mdv2010.0
+ Revision: 450614
- Recompile to fix Mandriva bug #54120

* Mon Sep 28 2009 Funda Wang <fwang@mandriva.org> 2.4-3mdv2010.0
+ Revision: 450603
- rebuild for new python-sip

* Wed Jul 22 2009 Helio Chissini de Castro <helio@mandriva.com> 2.4-2mdv2010.0
+ Revision: 398522
- Rebuild against current python-qt4

* Sat Jun 06 2009 Funda Wang <fwang@mandriva.org> 2.4-1mdv2010.0
+ Revision: 383208
- New version 2.4

* Sat Dec 27 2008 Funda Wang <fwang@mandriva.org> 2.3.2-2mdv2009.1
+ Revision: 319759
- rebuild for new python

* Tue Nov 18 2008 Funda Wang <fwang@mandriva.org> 2.3.2-1mdv2009.1
+ Revision: 304176
- New version 2.3.2

* Sun Nov 09 2008 Funda Wang <fwang@mandriva.org> 2.3.1-1mdv2009.1
+ Revision: 301228
- New version 2.3.1

* Sat Oct 11 2008 Funda Wang <fwang@mandriva.org> 2.3-1mdv2009.1
+ Revision: 292162
- New version 2.3

* Tue Sep 30 2008 Helio Chissini de Castro <helio@mandriva.com> 2.2-5mdv2009.0
+ Revision: 290245
- Broken repository plus still valid qt3 plugins are causing segfaults in qt4 designer and python qt4 apps depending on qscintilla

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 2.2-4mdv2009.0
+ Revision: 265589
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Jun 04 2008 Helio Chissini de Castro <helio@mandriva.com> 2.2-3mdv2009.0
+ Revision: 215017
- No more qt3 build, added a switch
- Added easy provides for build

* Thu May 22 2008 Funda Wang <fwang@mandriva.org> 2.2-2mdv2009.0
+ Revision: 209983
- rediff libdir patch
- New version 2.2

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Sep 21 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 2.1-3mdv2008.0
+ Revision: 91997
- Rebuild for missing packages

* Wed Aug 22 2007 Helio Chissini de Castro <helio@mandriva.com> 2.1-2mdv2008.0
+ Revision: 68766
- Fix designer plugin build
- New upstream release
- Qt3 and Qt4 builds
- Need take a little more care with package naming
- New qscintilla release. With both qt 3 and 4 bindings, a small package name change was needed.
  Until new python-qt build against new scintilla, luma and eric3 will be broken. With python-qt4,
  eric3 will be obsoleted in favour of eric4.

* Tue May 22 2007 Helio Chissini de Castro <helio@mandriva.com> 1.7.1-2mdv2008.0
+ Revision: 29892
- Easy upgrade on qscintilla

* Tue May 08 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.7.1-1mdv2008.0
+ Revision: 25028
- fix build on x86_64
- spec file clean
- update to the latest version
- drop P0
- Import qscintilla



* Sun Jun 25 2006 Laurent MONTEL <lmontel@mandriva.com> 1.6-6
- Rebuild with new libpng

* Fri Dec 16 2005 Austin Acton <austin@mandriva.org> 1.6-5mdk
- mkrel

* Wed Nov 16 2005 Austin Acton <austin@mandriva.org> 1.6-4mdk
- ease upgrades (thanks Buchan)

* Thu Nov 10 2005 Austin Acton <austin@mandriva.org> 1.6-3mdk
- more install fixing

* Wed Nov 9 2005 Austin Acton <austin@mandriva.org> 1.6-2mdk
- split off translations
- fix install

* Tue Nov 8 2005 Austin Acton <austin@mandriva.org> 1.6-1mdk
- 1.6

* Thu Aug 25 2005 Austin Acton <austin@mandriva.org> 1.5.1-1mdk
- 1.5.1

* Mon Aug 22 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.5-2mdk
- lib64 fixes + let qmake decide the right QMAKESPEC

* Sun Feb 20 2005 Austin Acton <austin@mandrake.org> 1.5-1mdk
- 1.5

* Tue Sep 21 2004 Austin Acton <austin@mandrake.org> 1.4-2mdk
- major 5

* Mon Sep 20 2004 Lenny Cartier <lenny@mandrakesoft.com> 1.4-1mdk
- 1.4

* Tue Jul 06 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 1.3-3mdk
- Fix ldconfig

* Fri Jun 18 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 1.3-2mdk
- Rebuild

* Tue Jun 1 2004 Austin Acton <austin@mandrake.org> 1.2-1mdk
- 1.3
- major 4
- try to make it more sane and less linty

* Wed Aug 20 2003 Austin Acton <aacton@yorku.ca> 1.2-1mdk
- 1.2
- major 3

* Tue Jul 15 2003 Austin Acton <aacton@yorku.ca> 1.1-2mdk
- rebuild for rpm

* Fri May 23 2003 Austin Acton <aacton@yorku.ca> 1.1-1mdk
- new URL
- new version
- new major

* Fri May 02 2003 Lenny Cartier <lenny@mandrakesoft.com> 1.0-1mdk
- more mklibname
- from Jérôme Martin <jerome.f.martin@free.fr> :
	- Version 1.0 (for sip/pyqt 3.6)

* Sat Mar  8 2003 Jerome Martin <jerome.f.martin@free.fr> 0.3-2mdk
- Fix pb

* Mon Dec  2 2002 Jerome Martin <jerome.f.martin@free.fr> 0.3-1mdk
- First release
